@@ -3,7 +3,7 @@ A collection of ECG heartbeat detection algorithms implemented
 in Python. Developed in conjunction with a new ECG database:
 http://researchdata.gla.ac.uk/716/
 
-Copyright (C) 2019-2022 Luis Howell & Bernd Porr
+Copyright (C) 2019-2023 Luis Howell & Bernd Porr
 GPL GNU GENERAL PUBLIC LICENSE Version 3, 29 June 2007
 """
 
@@ -669,45 +669,45 @@ def panPeakDetect(detection, fs):
     missed_peaks = []
     peaks = []
 
-    for i in range(len(detection)):
+    for i in range(1,len(detection)-1):
+        if detection[i-1]<detection[i] and detection[i+1]<detection[i]:
+            peak = i
+            peaks.append(i)
 
-        if i>0 and i<len(detection)-1:
-            if detection[i-1]<detection[i] and detection[i+1]<detection[i]:
-                peak = i
-                peaks.append(i)
+            if detection[peak]>threshold_I1 and (peak-signal_peaks[-1])>0.3*fs:
+                    
+                signal_peaks.append(peak)
+                indexes.append(index)
+                SPKI = 0.125*detection[signal_peaks[-1]] + 0.875*SPKI
+                if RR_missed!=0:
+                    if signal_peaks[-1]-signal_peaks[-2]>RR_missed:
+                        missed_section_peaks = peaks[indexes[-2]+1:indexes[-1]]
+                        missed_section_peaks2 = []
+                        for missed_peak in missed_section_peaks:
+                            if missed_peak-signal_peaks[-2]>min_distance and signal_peaks[-1]-missed_peak>min_distance and detection[missed_peak]>threshold_I2:
+                                missed_section_peaks2.append(missed_peak)
 
-                if detection[peak]>threshold_I1 and (peak-signal_peaks[-1])>0.3*fs:
-                        
-                    signal_peaks.append(peak)
-                    indexes.append(index)
-                    SPKI = 0.125*detection[signal_peaks[-1]] + 0.875*SPKI
-                    if RR_missed!=0:
-                        if signal_peaks[-1]-signal_peaks[-2]>RR_missed:
-                            missed_section_peaks = peaks[indexes[-2]+1:indexes[-1]]
-                            missed_section_peaks2 = []
-                            for missed_peak in missed_section_peaks:
-                                if missed_peak-signal_peaks[-2]>min_distance and signal_peaks[-1]-missed_peak>min_distance and detection[missed_peak]>threshold_I2:
-                                    missed_section_peaks2.append(missed_peak)
+                        if len(missed_section_peaks2)>0:
+                            signal_missed = [detection[i] for i in missed_section_peaks2]
+                            index_max = np.argmax(signal_missed)
+                            missed_peak = missed_section_peaks2[index_max]
+                            missed_peaks.append(missed_peak)
+                            signal_peaks.append(signal_peaks[-1])
+                            signal_peaks[-2] = missed_peak   
 
-                            if len(missed_section_peaks2)>0:           
-                                missed_peak = missed_section_peaks2[np.argmax(detection[missed_section_peaks2])]
-                                missed_peaks.append(missed_peak)
-                                signal_peaks.append(signal_peaks[-1])
-                                signal_peaks[-2] = missed_peak   
+            else:
+                noise_peaks.append(peak)
+                NPKI = 0.125*detection[noise_peaks[-1]] + 0.875*NPKI
 
-                else:
-                    noise_peaks.append(peak)
-                    NPKI = 0.125*detection[noise_peaks[-1]] + 0.875*NPKI
+            threshold_I1 = NPKI + 0.25*(SPKI-NPKI)
+            threshold_I2 = 0.5*threshold_I1
 
-                threshold_I1 = NPKI + 0.25*(SPKI-NPKI)
-                threshold_I2 = 0.5*threshold_I1
+            if len(signal_peaks)>8:
+                RR = np.diff(signal_peaks[-9:])
+                RR_ave = int(np.mean(RR))
+                RR_missed = int(1.66*RR_ave)
 
-                if len(signal_peaks)>8:
-                    RR = np.diff(signal_peaks[-9:])
-                    RR_ave = int(np.mean(RR))
-                    RR_missed = int(1.66*RR_ave)
-
-                index = index+1      
+            index = index+1      
     
     signal_peaks.pop(0)
 
